#!/bin/sh
# OpenOCD cross compile build script
#

libusb="libusb-win32-bin-1.2.6.0"
libusb_src="libusb-win32-src-1.2.6.0"
libusb_suffix=".zip"
libusb_decompress="unzip -q"
libusb_arch=amd64
libusb_dll=libusb0.dll
libftdi="libftdi-0.20"
libftdi_suffix=".tar.gz"
libftdi_decompress="tar xzf"
openocd="openocd-0.6.0"
openocd_suffix=".tar.bz2"
openocd_decompress="tar xjf"

# cross_host="i686-pc-mingw32"
cross_host="x86_64-w64-mingw32"

if [ ! -d $libusb ]; then
	if [ ! -f $libusb$libusb_suffix ]; then
		echo "$libusb$libusb_suffix is not exist!"
		exit 1
	fi
	echo "extracting $libusb ..."
	$libusb_decompress $libusb$libusb_suffix
fi

if [ ! -d $libusb_src ]; then
	if [ ! -f $libusb_src$libusb_suffix ]; then
		echo "$libusb_src$libusb_suffix is not exist!"
		exit 1
	fi
	echo "extracting $libusb_src ..."
	$libusb_decompress $libusb_src$libusb_suffix
fi

if [ ! -d $libftdi ]; then
	if [ ! -f $libftdi$libftdi_suffix ]; then
		echo "$libftdi$libftdi_suffix is not exist!"
		exit 1
	fi
	echo "extracting $libftdi ..."
	$libftdi_decompress $libftdi$libftdi_suffix
fi

if [ ! -d $openocd ]; then
	if [ ! -f $openocd$openocd_suffix ]; then
		echo "$openocd$openocd_suffix is not exist!"
		exit 1
	fi
	echo "extracting $openocd ..."
	$openocd_decompress $openocd$openocd_suffix
fi

root=`pwd`
echo "
# This is automatically generated makefile
all: libusb libftdi openocd
build:
	mkdir -p \$@
distclean:
	rm -rf $libusb $libusb_src $libftdi $openocd Makefile build
" > Makefile

pushd $root/$libusb
if [ ! -f include/usb.h ]; then
	cp include/lusb0_usb.h include/usb.h
fi
popd
echo "
libusb: build
	$cross_host-dlltool -l $libusb/lib/libusb.a -D $libusb_dll -d $libusb_src/libusb0.def $libusb/bin/$libusb_arch/$libusb_dll
	cp -r $root/$libusb/bin \$</usbdriver
" >> Makefile

pushd $root/$libftdi
if [ ! -f Makefile ]; then
	echo "
--- libftdi_old/examples/serial_test.c	2012-01-26 20:40:48.000000000 +0900
+++ libftdi_new/examples/serial_test.c	2012-09-30 16:20:00.655026208 +0900
@@ -159,7 +159,7 @@
         else
             f = ftdi_read_data(ftdi, buf, sizeof(buf));
         if (f<0)
-            sleep(1);
+            Sleep(1);
         else if(f> 0 && !do_write)
         {
             fprintf(stderr, \"read %d bytes\\n\", f);
	" | patch -f -p1
	./configure --host=$cross_host CFLAGS="-I$root/$libusb/include" LDFLAGS="-L$root/$libusb/lib"
fi
popd
echo "
libftdi:
	cd $root/$libftdi; make
" >> Makefile

pushd $root/$openocd
if [ ! -f Makefile ]; then
	echo "
--- openocd_old/src/rtos/linux.c	2012-09-07 17:21:47.000000000 +0900
+++ openocd_new/src/rtos/linux.c	2012-09-30 16:25:27.471691114 +0900
@@ -36,6 +36,10 @@
 
 #define LINUX_USER_KERNEL_BORDER 0xc0000000
 #include \"linux_header.h\"
+#undef PRId64
+#undef PRIx64
+#define PRId64 \"lld\"
+#define PRIx64 \"llx\"
 #define PHYS
 #define MAX_THREADS 200
 /*  specific task  */
--- openocd_old/src/rtos/FreeRTOS.c	2012-09-07 17:21:47.000000000 +0900
+++ openocd_new/src/rtos/FreeRTOS.c	2012-09-30 16:24:52.679300510 +0900
@@ -29,6 +29,8 @@
 #include \"rtos.h\"
 #include \"helper/log.h\"
 #include \"rtos_standard_stackings.h\"
+#undef PRId64
+#define PRId64 \"lld\"
 
 #define FREERTOS_MAX_PRIORITIES	63
 
	" | patch -f -p1
	./configure --host=$cross_host \
		--enable-ft2232_libftdi \
		--enable-arm-jtag-ew \
		--enable-jlink \
		--enable-stlink \
		--enable-usb_blaster_libftdi \
		CFLAGS="-I$root/$libusb/include -I$root/$libftdi/src" \
		LDFLAGS="-L$root/$libusb/lib -L$root/$libftdi/src"
fi
popd
echo "
openocd: build
	make -C $root/$openocd
	cp $root/$openocd/src/openocd.exe \$<
	cp -r $root/$openocd/tcl \$<
" >> Makefile

